==> dde-introduction_6.5.17.1.tar.xz: BUILD/translations/dde-introduction_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Align center</source>
        <translation>居中</translation>
    </message>
    <message>
        <source>Align left</source>
        <translation>靠左</translation>
    </message>
</context>
<context>
    <name>IconModule</name>
    <message>
        <source>Social Communication</source>
        <translation>社交通訊</translation>
    </message>
    <message>
        <source>Office Software</source>
        <translation>辦公軟件</translation>
    </message>
    <message>
        <source>Operation tools</source>
        <translation>運維工具</translation>
    </message>
    <message>
        <source>More Apps</source>
        <translation>更多應用</translation>
    </message>
    <message>
        <source>Common App Libraries</source>
        <translation>常用應用庫</translation>
    </message>
    <message>
        <source>How to get started quickly with UOS</source>
        <translation>如何快速上手統信UOS</translation>
    </message>
    <message>
        <source>Learn basics operations</source>
        <translation>了解基本操作</translation>
    </message>
    <message>
        <source>Video Tutorials</source>
        <translation>影片操作指南</translation>
    </message>
    <message>
        <source>Enter the App Store</source>
        <translation>前往應用商店</translation>
    </message>
    <message>
        <source>View Manuals</source>
        <translation>查看幫助手冊</translation>
    </message>
    <message>
        <source>Install some frequently used applications</source>
        <translation>安裝一些常用的應用程式</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Getting Started</source>
        <translation>開始使用</translation>
    </message>
    <message>
        <source>See more</source>
        <translation>查看更多</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>Getting Ready</source>
        <translation>準備就緒</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>請選擇桌面樣式</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>歡迎</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WidgetManager</name>
    <message>
        <source>You can switch &quot;Alignment&quot; by right-clicking on the dock.</source>
        <translation>您可以在任務欄右鍵菜單-“應用佈局”中進行調節。</translation>
    </message>
</context>
</TS>

==> dde-introduction_6.5.25.tar.xz: BUILD/translations/dde-introduction_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>DesktopModeModule</name>
    <message>
        <source>Align center</source>
        <translation>居中</translation>
    </message>
    <message>
        <source>Align left</source>
        <translation>靠左</translation>
    </message>
</context>
<context>
    <name>IconModule</name>
    <message>
        <source>Social Communication</source>
        <translation>社交通訊</translation>
    </message>
    <message>
        <source>Office Software</source>
        <translation>辦公軟件</translation>
    </message>
    <message>
        <source>Operation tools</source>
        <translation>運維工具</translation>
    </message>
    <message>
        <source>More Apps</source>
        <translation>更多應用</translation>
    </message>
    <message>
        <source>Common App Libraries</source>
        <translation>常用應用庫</translation>
    </message>
    <message>
        <source>How to get started quickly with UOS</source>
        <translation>如何快速上手統信UOS</translation>
    </message>
    <message>
        <source>Learn basics operations</source>
        <translation>了解基本操作</translation>
    </message>
    <message>
        <source>Video Tutorials</source>
        <translation>影片操作指南</translation>
    </message>
    <message>
        <source>Enter the App Store</source>
        <translation>前往應用商店</translation>
    </message>
    <message>
        <source>View Manuals</source>
        <translation>查看幫助手冊</translation>
    </message>
    <message>
        <source>Install some frequently used applications</source>
        <translation>安裝一些常用的應用程式</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Getting Started</source>
        <translation>開始使用</translation>
    </message>
    <message>
        <source>See more</source>
        <translation>查看更多</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>上一頁</translation>
    </message>
    <message>
        <source>Getting Ready</source>
        <translation>準備就緒</translation>
    </message>
    <message>
        <source>Choose a desktop mode</source>
        <translation>請選擇桌面樣式</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Welcome</source>
        <translation>歡迎</translation>
    </message>
</context>
<context>
    <name>WMModeModule</name>
    <message>
        <source>Normal Mode</source>
        <translation>標準模式</translation>
    </message>
    <message>
        <source>Effect Mode</source>
        <translation>特效模式</translation>
    </message>
</context>
<context>
    <name>WidgetManager</name>
    <message>
        <source>You can switch &quot;Alignment&quot; by right-clicking on the dock.</source>
        <translation>您可以在任務欄右鍵菜單-“應用佈局”中進行調節。</translation>
    </message>
</context>
</TS>
